TableState

Struct TableState 

pub struct TableState<T> {
    pub items: Vec<T>,
    pub selected: usize,
    pub loading: bool,
    pub filter: String,
    pub page_size: PageSize,
    pub expanded_item: Option<usize>,
    pub scroll_offset: usize,
    pub next_token: Option<String>,
}
Generic table state for list-based services

Fields

items: Vec<T>selected: usizeloading: boolfilter: Stringpage_size: PageSizeexpanded_item: Option<usize>scroll_offset: usizenext_token: Option<String>

Implementations

Source

impl<T> TableState<T>

pub fn new() -> Self

pub fn filtered<F>(&self, predicate: F) -> Vec<&T>
where F: Fn(&T) -> bool,

pub fn paginate<'a>(&self, filtered: &'a [&'a T]) -> &'a [&'a T]

pub fn current_page(&self, _total_items: usize) -> usize

pub fn total_pages(&self, total_items: usize) -> usize

pub fn next_item(&mut self, max: usize)

pub fn prev_item(&mut self)

pub fn page_down(&mut self, max: usize)

pub fn page_up(&mut self)

pub fn snap_to_page(&mut self)

pub fn toggle_expand(&mut self)

pub fn collapse(&mut self)

pub fn expand(&mut self)

pub fn is_expanded(&self) -> bool

pub fn has_expanded_item(&self) -> bool

pub fn goto_page(&mut self, page: usize, total_items: usize)

pub fn reset(&mut self)

pub fn get_selected<'a>(&self, filtered: &'a [&'a T]) -> Option<&'a T>

pub fn filter_push(&mut self, c: char)

Push a character to the filter and reset selection

pub fn filter_pop(&mut self)

Pop a character from the filter and reset selection

pub fn filter_clear(&mut self)

Clear the filter and reset selection