Module ui

Module ui 

Re-exports

pub use cw::insights::DateRangeType;
pub use cw::insights::TimeUnit;
pub use cw::CloudWatchLogGroupsState;
pub use cw::DetailTab;
pub use cw::EventColumn;
pub use cw::EventFilterFocus;
pub use cw::LogGroupColumn;
pub use cw::StreamColumn;
pub use cw::StreamSort;
pub use prefs::Preferences;
pub use table::format_expandable;
pub use table::CURSOR_COLLAPSED;
pub use table::CURSOR_EXPANDED;

Modules

apig
cfn
cloudtrail
cw
ec2
ecr
filter
iam
lambda
monitoring
prefs
s3
sqs
styles
table
tree

Structs

PaginatedFilterConfig
QueryEditorConfig

Constants

MAX_DETAIL_COLUMNS
PAGE_SIZE_OPTIONS
PAGE_SIZE_OPTIONS_SMALL
PREFERENCES_TITLE
SEARCH_ICON
SPINNER_FRAMES

Functions

active_border
block
block_height
Calculate the height needed for a block containing lines (lines + 2 for borders)
block_height_for
Calculate the height needed for a block with a given number of lines (lines + 2 for borders)
block_with_style
bold_style
calculate_dynamic_height
Calculates the height needed for fields with dynamic columns (without rendering)
cyan_bold
filter_area
first_hint
format_duration
format_expansion_text
Format key-value pairs for expansion (used in table rows)
format_fields
Format multiple fields as lines
format_title
get_cursor
hint
horizontal
labeled_field
last_hint
red_text
render
render_fields_with_dynamic_columns
Renders fields in dynamic columns based on available width Returns the height needed for the content
render_json_highlighted
render_last_accessed_section
render_paginated_filter
render_permissions_section
render_query_editor
render_search_filter
render_summary
render_tab_spans
render_tabs
render_tags_section
rounded_block
section_header
service_tab_style
tab_style
titled_block
titled_rounded_block
vertical
yellow_text