Module tree

Module tree 

Structs

TreeRenderer
Generic tree renderer that handles hierarchical display with expand/collapse

Constants

CURSOR_COLLAPSED
CURSOR_EXPANDED

Traits

TreeItem
Trait for items that can be displayed in a tree structure