Re-exports
pub use cw::insights::DateRangeType;pub use cw::insights::TimeUnit;pub use cw::CloudWatchLogGroupsState;pub use cw::DetailTab;pub use cw::EventColumn;pub use cw::EventFilterFocus;pub use cw::LogGroupColumn;pub use cw::StreamColumn;pub use cw::StreamSort;pub use prefs::Preferences;pub use table::format_expandable;pub use table::CURSOR_COLLAPSED;pub use table::CURSOR_EXPANDED;
Modules
Structs
Constants
- MAX_
DETAIL_ COLUMNS - PAGE_
SIZE_ OPTIONS - PAGE_
SIZE_ OPTIONS_ SMALL - PREFERENCES_
TITLE - SEARCH_
ICON - SPINNER_
FRAMES
Functions
- active_
border - block
- block_
height - Calculate the height needed for a block containing lines (lines + 2 for borders)
- block_
height_ for - Calculate the height needed for a block with a given number of lines (lines + 2 for borders)
- block_
with_ style - bold_
style - calculate_
dynamic_ height - Calculates the height needed for fields with dynamic columns (without rendering)
- cyan_
bold - filter_
area - first_
hint - format_
duration - format_
expansion_ text - Format key-value pairs for expansion (used in table rows)
- format_
fields - Format multiple fields as lines
- format_
title - get_
cursor - hint
- horizontal
- labeled_
field - last_
hint - red_
text - render
- render_
fields_ with_ dynamic_ columns - Renders fields in dynamic columns based on available width Returns the height needed for the content
- render_
json_ highlighted - render_
last_ accessed_ section - render_
paginated_ filter - render_
permissions_ section - render_
query_ editor - render_
search_ filter - render_
summary - render_
tab_ spans - render_
tabs - render_
tags_ section - rounded_
block - section_
header - service_
tab_ style - tab_
style - titled_
block - titled_
rounded_ block - vertical
- yellow_
text